@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 
-from energytt_platform.serialize import Serializable
+from energytt_platform.bus import Message
 from energytt_platform.models.measurements import Measurement
 
 
 @dataclass
-class MeasurementAdded(Serializable):
+class MeasurementAdded(Message):
     """
     A new Measurement has been added to the system.
     """
